##  Focusing on Specific Capabilities
When assessing applications that support "Innovation", for example, consider the following key questions:
  * Are these capabilities still reliant on legacy technologies?
  * Which applications could benefit from cloud migration to enhance scalability and agility?
  * Is the current technology stack suitable for implementing innovative ideas, or are there signs of obsolescence?


For the last point, we recommend using [SAP LeanIX Technology Risk and Compliance](https://help.sap.com/docs/leanix/ea/sap-leanix-technology-risk-and-compliance?locale=en-US&state=PRODUCTION&version=CLOUD "Get an overview of SAP LeanIX Technology Risk and Compliance, with links to detailed guides for managing obsolescence risk, optimizing technology usage, and enforcing tech standards across your IT landscape.") to gain detailed insights into technology risks and outdated components.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2749ac167a4410148db5a6a552f5bd29_LowRes.png)
